
# Slot: model_taxon_closure

The reflexive transitive closure of the taxon term for the model, over the NCBITaxon:subClassOf relationship type. This is used to determine the set of taxa that are relevant to the model.

URI: [gocam:queryIndex__model_taxon_closure](https://w3id.org/gocam/queryIndex__model_taxon_closure)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [TermObject](TermObject.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
